==> haskell-megaparsec6-6.5.0-16-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-megaparsec6.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: megaparsec
version: 6.5.0
id: megaparsec-6.5.0-JcMuTpPcDBCKI6106QX1Ns
key: megaparsec-6.5.0-JcMuTpPcDBCKI6106QX1Ns
license: BSD-2-Clause
maintainer: Mark Karpov <markkarpov92@gmail.com>
author: Megaparsec contributors,
        Paolo Martini <paolo@nemail.it>,
        Daan Leijen <daan@microsoft.com>
homepage: https://github.com/mrkkrp/megaparsec
synopsis: Monadic parser combinators
description:
    This is an industrial-strength monadic parser combinator library.
    Megaparsec is a feature-rich package that strikes a nice balance between
    speed, flexibility, and quality of parse errors.
category: Parsing
abi: e927ad09f773d656d3aeb39c0c904a30
exposed: True
exposed-modules:
    Text.Megaparsec Text.Megaparsec.Byte Text.Megaparsec.Byte.Lexer
    Text.Megaparsec.Char Text.Megaparsec.Char.Lexer
    Text.Megaparsec.Error Text.Megaparsec.Error.Builder
    Text.Megaparsec.Expr Text.Megaparsec.Internal Text.Megaparsec.Perm
    Text.Megaparsec.Pos Text.Megaparsec.Stream
hidden-modules: Text.Megaparsec.Class Text.Megaparsec.State
import-dirs: /usr/lib/ghc-8.6.5/site-local/megaparsec-6.5.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/megaparsec-6.5.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/megaparsec-6.5.0
hs-libraries: HSmegaparsec-6.5.0-JcMuTpPcDBCKI6106QX1Ns
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk containers-0.6.0.1
    deepseq-1.4.4.0 mtl-2.2.2
    parser-combinators-1.0.2-IyNQpKDV9bJE8mJzaajfJ
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b text-1.2.3.1
    transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-megaparsec6/html/megaparsec.haddock
haddock-html: /usr/share/doc/haskell-megaparsec6/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-megaparsec6-6.5.0-17-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-megaparsec6.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: megaparsec
version: 6.5.0
id: megaparsec-6.5.0-259wkzB1AyYCgUm93l3wbb
key: megaparsec-6.5.0-259wkzB1AyYCgUm93l3wbb
license: BSD-2-Clause
maintainer: Mark Karpov <markkarpov92@gmail.com>
author: Megaparsec contributors,
        Paolo Martini <paolo@nemail.it>,
        Daan Leijen <daan@microsoft.com>
homepage: https://github.com/mrkkrp/megaparsec
synopsis: Monadic parser combinators
description:
    This is an industrial-strength monadic parser combinator library.
    Megaparsec is a feature-rich package that strikes a nice balance between
    speed, flexibility, and quality of parse errors.
category: Parsing
abi: 383ad118ff3581e4703287b679cbaf02
exposed: True
exposed-modules:
    Text.Megaparsec Text.Megaparsec.Byte Text.Megaparsec.Byte.Lexer
    Text.Megaparsec.Char Text.Megaparsec.Char.Lexer
    Text.Megaparsec.Error Text.Megaparsec.Error.Builder
    Text.Megaparsec.Expr Text.Megaparsec.Internal Text.Megaparsec.Perm
    Text.Megaparsec.Pos Text.Megaparsec.Stream
hidden-modules: Text.Megaparsec.Class Text.Megaparsec.State
import-dirs: /usr/lib/ghc-8.6.5/site-local/megaparsec-6.5.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/megaparsec-6.5.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/megaparsec-6.5.0
hs-libraries: HSmegaparsec-6.5.0-259wkzB1AyYCgUm93l3wbb
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk containers-0.6.0.1
    deepseq-1.4.4.0 mtl-2.2.2
    parser-combinators-1.0.3-1G8nppuMEiR2Ao7u4R9lsu
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b text-1.2.3.1
    transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-megaparsec6/html/megaparsec.haddock
haddock-html: /usr/share/doc/haskell-megaparsec6/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
